/* eslint-disable react/prop-types */
import React, {useState} from 'react'

import FormControl from '@material-ui/core/FormControl'
import FormHelperText from '@material-ui/core/FormHelperText'
import Input from '@material-ui/core/Input'
import InputLabel from '@material-ui/core/InputLabel'
import MenuItem from '@material-ui/core/MenuItem'
import Select from '@material-ui/core/Select'

import {useStyles} from '../index'


export default function MCF_Select (props) {
  const [params, setParams] = useState(props.params)
  const classes = useStyles()

  const handleInteraction = event => {
    const option = params.options.find(option => option.value === event.target.value)
    params.value = option.value
    if (params.onSelectListener) params.onSelectListener(option.id, option.value)
    setParams(params)
  }
  const createList = () => {
    return (
      params.options.map(option => {
        return (
          <MenuItem
            key={option.id}
            value={option.value}
          >
            {option.label}
          </MenuItem>
        )
      })
    )
  }

  return (
    <FormControl
      className={classes.formControl}
      disabled={params.disabled}
      error={params.error}
      required={params.required}
    >
      <InputLabel
        shrink={params.shrink}
        htmlFor={params.id}
      >
        {params.label}
      </InputLabel>
      <Select
        value={params.value}
        displayEmpty={params.displayEmpty}
        autoWidth={params.autoWidth}
        onChange={handleInteraction}
        input={<Input
          name={params.id}
          id={params.id}
          readOnly={params.readOnly}
        />}
      >
        {createList()}
      </Select>
      <FormHelperText>
        {params.helperText}
      </FormHelperText>
    </FormControl>
  )
}
